/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

var App = require('app');
var view;
describe('App.FilterComboCleanableView', function() {

  beforeEach(function() {
    view = App.FilterComboCleanableView.create();
  });

  describe.skip('#didInsertElement', function() {

    beforeEach(function () {
      sinon.stub(App, 'popover', Em.K);
    });

    afterEach(function () {
      App.popover.restore();
    });

    it('should clean filter when created', function() {
      view.setProperties({
        filter: 'some value',
        popoverDescription: ['', '']
      });
      view.didInsertElement();
      expect(view.get('filter')).to.be.empty;
    });

  });

});